/*
The output of DataOutputStream.writeUTF() is a custom format, intended to be read by DataInputStream.readUTF().

The javadocs of the writeUTF method you are calling say:

Writes a string to the underlying output stream using modified UTF-8 encoding in a machine-independent manner.

First, two bytes are written to the output stream as if by the writeShort method giving the number of bytes to follow.
This value is the number of bytes actually written out, not the length of the string.
Following the length, each character of the string is output, in sequence, using the modified UTF-8 encoding for the character.
If no exception is thrown, the counter written is incremented by the total number of bytes written to the output stream.
This will be at least two plus the length of str, and at most two plus thrice the length of str.

UTF stands for Unicode Transformation Format. The '8' means it uses 8-bit blocks to represent a character.
*/

import java.net.*;
import java.io.*;
public class TCPServer
{
    public static void main(String args[])
    {
        int port = 7000;

        ServerSocket serverSocket = null;
        DataInputStream dataInputStream = null;
        DataOutputStream dataOutputStream = null;

        try
        {
            // open a server socket
            serverSocket = new ServerSocket(port);

            System.out.println("Server created on port "+port);
            System.out.println("Awaiting client connection...");

            // await for a client connection
            Socket clientSocket = serverSocket.accept();
            System.out.println("Client connected from"+clientSocket.getInetAddress());

            dataInputStream = new DataInputStream(clientSocket.getInputStream());
           dataOutputStream = new DataOutputStream(clientSocket.getOutputStream());
        }
       catch(IOException e)
       {
           System.out.println("Problems initializing server: "+e);
           System.exit(1);
       }
       // communicate with the client
       try
       {
           dataOutputStream.writeUTF("Welcome to the TCP Echo Server!");

           String input;
           while(true)
           {
             // read data in from client
             input = dataInputStream.readUTF();
             System.out.println("You typed: "+input);
             // write data back to client
             dataOutputStream.writeUTF(input);
           }
        }
        catch(IOException e)
        {
             System.out.println("Client disconnected from server");
        }
        try
        {
            serverSocket.close();
        }
        catch(Exception e) { }
    }

}